We should use load_bias.  This patch fixes MIPS NDK device exception test failures.

Change-Id: I4b718c36666e66062c1f13e4deea1ec7a7951c54
diff --git a/linker/linker.cpp b/linker/linker.cpp
index 409580e..fc54f3a 100755
--- a/linker/linker.cpp
+++ b/linker/linker.cpp
@@ -1928,12 +1928,12 @@
         preloads[i]->CallConstructors();
     }
 
     /*After the link_image, the si->base is initialized.
      *For so lib, the map->l_addr will be updated in notify_gdb_of_load.
      *We need to update this value for so exe here. So Unwind_Backtrace
      *for some arch like x86 could work correctly within so exe.
      */
-    map->l_addr = si->base;
+    map->l_addr = si->load_bias;
     si->CallConstructors();
 
 #if TIMING
@@ -1928,12 +1928,12 @@
     }
 
-    /*After the link_image, the si->base is initialized.
+    /*After the link_image, the si->load_bias is initialized.
      *For so lib, the map->l_addr will be updated in notify_gdb_of_load.
      *We need to update this value for so exe here. So Unwind_Backtrace